pub struct EncapEntry {
pub gateway: Ipv4Addr,
pub ty: String,
pub network: Ipv4Addr,
pub mask_len: u8,
pub title: String,
pub owner: String,
pub updated: String,
}Expand description
Describes an encapsulation entry
Fields
gateway: Ipv4AddrPublic IPv4 address of the gateway
ty: StringType of encapsulation (currently only ‘IPIP’ will appear here)
network: Ipv4AddrNetwork address of the route being announced by this gateway.
mask_len: u8Mask length of the network being announced
title: StringDescription of the gateway as supplied by the owner.
owner: StringCallsign of the owner / person responsible for this gateway.
updated: StringDate/time this gateway’s data was last altered.