pub async fn get_api_endpoints(
auth: &Auth,
) -> Result<HashMap<String, String>, Error>Expand description
Returns a list of available endpoints as key/value pairs.
The key contains the name of the endpoint, whilst the value contains the method for
accessing the endpoint, i.e. one of: GET, POST, PUT, PATCH or DELETE, followed by a
single space, followed by a brief description of each endpoint